Struct BasicFramebuffer
Source pub struct BasicFramebuffer {
pub fb_pointer: *mut u32,
pub bytes_per_row: u32,
pub width: u64,
pub height: u64,
}
A thin wrapper around the Limine-provided linear framebuffer.
Pointer to the first pixel; pixels are row-major, bytes_per_row per row.
Number of 32-bit pixels per row (Limine pitch / 4).
Construct a BasicFramebuffer from the Limine framebuffer descriptor.
Write zero (black) to every pixel in the framebuffer.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.